@@ -3,20 +3,18 @@
 """
     some decorators
     ~~~~~~~~~~~~~~~
-    
+
     from PyLucid decorators.
 
-    Last commit info:
-    ~~~~~~~~~~~~~~~~~
-    $LastChangedDate:$
-    $Rev:$
-    $Author: JensDiemer $
-
-    :copyleft: 2009-2010 by the PyLucid team, see AUTHORS for more details.
+    :copyleft: 2009-2016 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+from __future__ import absolute_import, division, print_function
+
+
 import sys
+import traceback
 import warnings
 from django.contrib import messages
 try:
@@ -24,7 +22,7 @@ try:
 except ImportError:
     from django.utils.functional import wraps  # Python 2.3, 2.4 fallback.
 
-
+from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
 from django.template import RequestContext
 from django.shortcuts import render_to_response
@@ -37,11 +35,11 @@ def check_permissions(superuser_only, permissions=()):
     """
     Protect a view and limit it to users witch are log in and has the permissions.
     If the user is not log in -> Redirect him to a log in view with a next_url back to the requested page.
-    
+
     TODO: Add a log entry, if user has not all permissions.
-    
+
     Usage:
-    --------------------------------------------------------------------------    
+    --------------------------------------------------------------------------
     @check_permissions(superuser_only=False, permissions=(u'appname.add_modelname', u'appname.change_modelname'))
     def my_view(request):
         ...
@@ -85,17 +83,17 @@ def render_to(template_name=None, debug=False, **response_kwargs):
     Based on the decorators from django-annoying.
 
     Example:
- 
+
         @render_to('foo/template.html')
         def PyLucidPluginFoo(request):
-            bar = Bar.object.all()  
+            bar = Bar.object.all()
             return {'bar': bar}
-        
+
     The view can also insert the template name in the context, e.g.:
 
         @render_to
         def PyLucidPluginFoo(request):
-            bar = Bar.object.all()  
+            bar = Bar.object.all()
             return {'bar': bar, 'template_name': 'foo/template.html'}
     """
     def renderer(function):
@@ -116,7 +114,7 @@ def render_to(template_name=None, debug=False, **response_kwargs):
                     msg = (
                         "renter_to info: %s (template: %r)"
                         " has not return a dict, has return: %r (%r)"
-                    ) % (function.__name__, template_name, type(context), function.func_code)
+                    ) % (function.__name__, template_name, type(context), function.__code__)
                     messages.info(request, msg)
                 return context
 
@@ -135,3 +133,27 @@ def render_to(template_name=None, debug=False, **response_kwargs):
             return response
         return wrapper
     return renderer
+
+
+def display_admin_error(func):
+    """
+    For temporary display errors in admin functions. e.g.:
+
+        class MyAdmin(admin.ModelAdmin):
+
+            @display_admin_error
+            def bsp(obj):
+                raise FooBar
+
+            list_display = ('bsp',)
+    """
+    def wrapped(*args, **kwargs):
+        try:
+            return func(*args, **kwargs)
+        except Exception as err:
+            traceback.print_exc(file=sys.stderr)
+            if settings.DEBUG:
+                return "%s: %s" % (err.__class__.__name__, err)
+            else:
+                raise
+    return wrapped
