@@ -3,16 +3,18 @@
 """
     Dynamic SITE ID
     ~~~~~~~~~~~~~~~
-    
+
     Set the SITE_ID dynamic by the current Domain Name.
-    
+
     More info: read .../django_tools/dynamic_site/README.creole
-    
-    :copyleft: 2011-2013 by the django-tools team, see AUTHORS for more details.
+
+    :copyleft: 2011-2015 by the django-tools team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+from __future__ import absolute_import, division, print_function
 
+import logging
 import os
 import sys
 import warnings
@@ -25,14 +27,13 @@ except ImportError:
 from django.conf import settings
 from django.contrib.sites import models as sites_models
 from django.core.exceptions import MiddlewareNotUsed, ImproperlyConfigured
-from django.utils import log
 
 from django_tools.local_sync_cache.local_sync_cache import LocalSyncCache
-from django_tools.dynamic_site.models import SiteAlias
+
 
 USE_DYNAMIC_SITE_MIDDLEWARE = getattr(settings, "USE_DYNAMIC_SITE_MIDDLEWARE", False)
 
-logger = log.getLogger("django_tools.DynamicSite")
+logger = logging.getLogger("django_tools.DynamicSite")
 
 
 Site = sites_models.Site  # Shortcut
@@ -56,7 +57,7 @@ class DynamicSiteId(object):
         return str(SITE_THREAD_LOCAL.SITE_ID)
     def __unicode__(self):
 #        print "DynamicSiteId __unicode__"
-        return unicode(SITE_THREAD_LOCAL.SITE_ID)
+        return str(SITE_THREAD_LOCAL.SITE_ID)
 
 
 def _clear_cache(self):
@@ -83,7 +84,7 @@ if USE_DYNAMIC_SITE_MIDDLEWARE == True:
 
     try:
         FALLBACK_SITE = Site.objects.get(id=FALLBACK_SITE_ID)
-    except Site.DoesNotExist, e:
+    except Site.DoesNotExist as e:
         all_sites = Site.objects.all()
         msg = "Fallback SITE_ID %i doesn't exist: %s (Existing sites: %s)" % (
             FALLBACK_SITE_ID, e, repr(all_sites.values_list("id", "domain").order_by('id'))
@@ -157,6 +158,7 @@ class DynamicSiteMiddleware(object):
             site = Site.objects.get(domain__iexact=host)
         except Site.DoesNotExist:
             # Look if there is a alias
+            from django_tools.dynamic_site.models import SiteAlias # against import loops ;(
             try:
                 site = SiteAlias.objects.get_from_host(host)
             except SiteAlias.DoesNotExist:
