@@ -3,20 +3,24 @@
 """
     sign separated
     ~~~~~~~~~~~~~~
-    
+
      * model field
      * form field
      * widget
 
-    :copyleft: 2010-2011 by the django-tools team, see AUTHORS for more details.
+    :copyleft: 2010-2015 by the django-tools team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+from __future__ import absolute_import, division, print_function
+
+
 if __name__ == "__main__":
     # For doctest only
     import os
-    os.environ["DJANGO_SETTINGS_MODULE"] = "django_tools.tests.test_settings"
+    os.environ["DJANGO_SETTINGS_MODULE"] = "django_tools.django_tools_tests.test_settings"
 
+from django.utils import six
 from django import forms
 from django.db import models
 
@@ -65,26 +69,28 @@ class SignSeparatedFormField(forms.CharField):
     """
     >>> SignSeparatedFormField().clean(u"one, two")
     (u'one', u'two')
-    
+
     >>> SignSeparatedFormField().to_python(u"one , two, 3,4")
     (u'one', u'two', u'3', u'4')
     >>> SignSeparatedFormField(strip_items=False).clean(u"one , two, 3,4")
     (u'one ', u' two', u' 3', u'4')
-    
+
     >>> SignSeparatedFormField(separator=" ").clean(u"one  two 3")
     (u'one', u'two', u'3')
     >>> SignSeparatedFormField(separator=" ", skip_empty=False).clean(u"one  two 3")
     (u'one', u'', u'two', u'3')
-    
-    >>> SignSeparatedFormField().clean(None)
-    Traceback (most recent call last):
-        ...
-    ValidationError: [u'This field is required.']
-    
-    >>> SignSeparatedFormField().clean("")
-    Traceback (most recent call last):
-        ...
-    ValidationError: [u'This field is required.']
+
+    >>> try:
+    ...     SignSeparatedFormField().clean(None)
+    ... except Exception as err:
+    ...     print(err.__class__.__name__, err)
+    ValidationError ['This field is required.']
+
+    >>> try:
+    ...     SignSeparatedFormField().clean("")
+    ... except Exception as err:
+    ...     print(err.__class__.__name__, err)
+    ValidationError ['This field is required.']
     """
     def __init__(self, separator=",", strip_items=True, skip_empty=True, *args, **kwargs):
         self.separator = separator
@@ -100,41 +106,43 @@ class SignSeparatedFormField(forms.CharField):
         return values
 
 
+# @six.add_metaclass(models.SubfieldBase)
 class SignSeparatedModelField(models.TextField):
     """
     A dict field.
     Stores a python dict into a text field.
-    
+
     >>> SignSeparatedModelField().to_python("foo, bar")
     ('foo', 'bar')
 
     >>> SignSeparatedModelField().get_db_prep_save(('foo', 'bar'))
     'foo,bar'
-    
+
     >>> f = SignSeparatedModelField().formfield()
     >>> isinstance(f, SignSeparatedFormField)
     True
     >>> f.clean(u"one , two, 3,4")
     (u'one', u'two', u'3', u'4')
-    
+
     kwargs would be pass to the widget:
     >>> f = SignSeparatedModelField(separator="x", strip_items=False, skip_empty=False).formfield()
     >>> f.clean("1x2x x 3")
     ('1', '2', ' ', ' 3')
-    
-    
+
+
     >>> from django.db import models
     >>> from django.forms.models import ModelForm
-        
+
     >>> class TestModel(models.Model):
     ...     test = SignSeparatedModelField(separator=";")
     ...     class Meta:
     ...         app_label = "django_tools"
-    
+
     >>> class TestForm(ModelForm):
     ...     class Meta:
     ...         model = TestModel
-    
+    ...         exclude=()
+
     >>> f = TestForm({'test': None})
     >>> f.is_valid()
     False
@@ -146,12 +154,7 @@ class SignSeparatedModelField(models.TextField):
     True
     >>> f.cleaned_data
     {'test': ('one', 'two', 'three')}
-    >>> from django.core import management
-    >>> management.call_command("syncdb", interactive=False, verbosity=0)
-    >>> f.save()
-    <TestModel: TestModel object>
     """
-    __metaclass__ = models.SubfieldBase
 
     def __init__(self, separator=",", strip_items=True, skip_empty=True, *args, **kwargs):
         self.separator = separator
@@ -188,8 +191,8 @@ class SignSeparatedModelField(models.TextField):
 if __name__ == "__main__":
     # Run all unittest directly
     import doctest
-    print doctest.testmod(
+    print(doctest.testmod(
 #        verbose=True
         verbose=False,
-    )
-    print "DocTest end."
+    ))
+    print("DocTest end.")
