@@ -4,7 +4,7 @@
     Local sync cache Middleware
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~
     
-    Calles check_state() in every existing LocalSyncCache instance.
+    Calls check_state() in every existing LocalSyncCache instance.
     
     For more information look into DocString in local_sync_cache.py !
     
@@ -12,6 +12,9 @@
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+from __future__ import absolute_import, division, print_function
+
+
 from django_tools.local_sync_cache.local_sync_cache import LocalSyncCache
 
 class LocalSyncCacheMiddleware(object):
