@@ -3,28 +3,28 @@
 """
     Local sync cache
     ~~~~~~~~~~~~~~~~
-    
+
     The Problem:
     If you use a normal dict for cache some values, you can't clear it in
     a multi-threaded environment, because you have no access to the dict in
     other threads.
-    
+
     The Solution:
     Use LocalSyncCache() as a cache dict. If dict.clear() called, the dict
     in all threads would be cleared.
-    
+
     How it works:
-    * Every cache dict memorize his own creation/reset time.  
+    * Every cache dict memorize his own creation/reset time.
     * in dict.clear() the reset time would be saved
       into django cache (to share it with all threads)
     * On every request the LocalSyncCacheMiddleware called all existing cache dict
-      in the current threads to look into the shared django cache, if they 
-      are outdatet or not. If they are outdated, the dict would be cleaned. 
-    
-    
+      in the current threads to look into the shared django cache, if they
+      are outdatet or not. If they are outdated, the dict would be cleaned.
+
+
     usage
     ~~~~~
-    
+
     Add LocalSyncCacheMiddleware to settings, e.g:
     ---------------------------------------------------------------------------
         MIDDLEWARE_CLASSES = (
@@ -33,72 +33,65 @@
             ...
         )
     ---------------------------------------------------------------------------
-    
+
 
     Create a cache dict with a id.
     Use it in a model, e.g.:
     ---------------------------------------------------------------------------
         from django.db import models
         from django_tools.local_sync_cache.local_sync_cache import LocalSyncCache
-        
+
         class PageTree(models.Model):
             parent = models.ForeignKey("self", null=True, blank=True)
             slug = models.SlugField()
-            
+
             _url_cache = LocalSyncCache(id="PageTree_absolute_url") # <<<---
             def get_absolute_url(self):
                 if self.pk in self._url_cache:
                     return self._url_cache[self.pk]
-        
+
                 if self.parent:
                     parent_url = self.parent.get_absolute_url()
                     url = parent_url + self.slug + "/"
                 else:
                     url = "/" + self.slug + "/"
-        
+
                 self._url_cache[self.pk] = url
                 return url
-                
-        def save(self, *args, **kwargs):  
+
+        def save(self, *args, **kwargs):
             self._url_cache.clear() # Clean the local url cache dict
             return super(PageTree, self).save(*args, **kwargs)
     ---------------------------------------------------------------------------
-    
-    
+
+
     logging
     ~~~~~~~
-    
+
     To enable logging, add this to your settings, e.g.:
-    
-        from django.utils import log
-        logger = log.getLogger("django_tools.local_sync_cache")
+
+        import logging
+        logger = logging.getLogger("django_tools.local_sync_cache")
         logger.setLevel(log.logging.DEBUG)
         logger.addHandler(log.logging.FileHandler("local_sync_cache.log"))
-    
-    
-    :copyleft: 2011-2012 by the django-tools team, see AUTHORS for more details.
+
+
+    :copyleft: 2011-2015 by the django-tools team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+from __future__ import absolute_import, division, print_function
+
+import logging
 import sys
 import time
 import datetime
 
 from django.conf import settings
-from django.core import cache
-from django.utils import log
+from django.core.cache import caches
 
 
-logger = log.getLogger("django_tools.local_sync_cache")
-
-#if "runserver" in sys.argv or "tests" in sys.argv:
-#    log.logging.basicConfig(format='%(created)f pid:%(process)d %(message)s')
-#    logger.setLevel(log.logging.DEBUG)
-#    logger.addHandler(log.logging.StreamHandler())
-
-#if not logger.handlers:
-#    # ensures we don't get any 'No handlers could be found...' messages
-#    logger.addHandler(log.NullHandler())
+logger = logging.getLogger("django_tools.local_sync_cache")
 
 
 LOCAL_SYNC_CACHE_BACKEND = getattr(settings, "LOCAL_SYNC_CACHE_BACKEND", "local_sync_cache")
@@ -122,13 +115,13 @@ def _get_cache():
         msg = "You should use Memcache, FileBasedCache or DatabaseCache and not: %s" % backend
         logger.critical(msg)
 
-    django_cache = cache.get_cache(cache_name)
+    django_cache = caches[cache_name]
     logger.debug("Use django '%s' cache: %r" % (cache_name, django_cache))
     return django_cache
 
 
 class LocalSyncCache(dict):
-    INIT_COUNTER = {} # Counts how often __init__ used, should allways be 1!
+    INIT_COUNTER = {} # Counts how often __init__ used, should always be 1!
 
     # Stores all existing instance, used in middleware to call check_state()
     CACHES = []
@@ -143,7 +136,7 @@ class LocalSyncCache(dict):
         if unique_ids:
             for existing_cache in self.CACHES:
                 if id == existing_cache.id:
-                    raise AssertionError(
+                    logger.error(
                         "ID %r was already used! It must be unique! (Existing ids are: %s)" % (
                             id, repr([i.id for i in self.CACHES])
                         )
@@ -160,7 +153,7 @@ class LocalSyncCache(dict):
             logger.error("Error: __init__ for %s was called to often!" % self.id)
             self.INIT_COUNTER[self.id] += 1
 
-        self.request_counter = 0 # Counts how often check_state called (Normaly called one time per request)
+        self.request_counter = 0 # Counts how often check_state called (Normally called one time per request)
         self.own_clear_counter = 0 # Counts how often clear called in this thread
         self.ext_clear_counter = 0 # Counts how often clears from external thread
 
@@ -260,7 +253,7 @@ class LocalSyncCache(dict):
             for attr in attributes:
                 output.append("%22s: %s" % (attr, getattr(instance, attr)))
 
-            for key, value in item.iteritems():
+            for key, value in item.items():
                 output.append("%22s: %r" % (key, value))
 
         return "\n".join(output)
