@@ -4,13 +4,18 @@
     models stuff
     ~~~~~~~~~~~~
 
-    :copyleft: 2011 by the django-tools team, see AUTHORS for more details.
+    :copyleft: 2011-2015 by the django-tools team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
+from __future__ import absolute_import, division, print_function
+
+
 
 from django.db import models
-from django.contrib.auth.models import User
+from django.conf import settings
+from django.utils.encoding import python_2_unicode_compatible
+
 try:
     from django.utils.timezone import now
 except ImportError:
@@ -18,8 +23,18 @@ except ImportError:
     now = datetime.now
 
 from django_tools.middlewares import ThreadLocal
+try:
+    # django 1.6
+    from django.contrib.auth import get_user_model
+    User = get_user_model()
+except:
+    # django 1.7
+    from django.apps import apps
+    user_app, user_model = settings.AUTH_USER_MODEL.split('.')
+    User = apps.get_app_config(user_app).get_model(user_model)
 
 
+@python_2_unicode_compatible
 class UpdateTimeBaseModel(models.Model):
     """
     Base model to automatically set:
@@ -33,6 +48,9 @@ class UpdateTimeBaseModel(models.Model):
     createtime = models.DateTimeField(default=now, editable=False, help_text="Create time")
     lastupdatetime = models.DateTimeField(default=now, editable=False, help_text="Time of the last change.")
 
+    def __str__(self): # to be overwritten
+        return "model instance ID:%s" % self.pk
+
     def save(self, *args, **kwargs):
         self.lastupdatetime = now()
         return super(UpdateTimeBaseModel, self).save(*args, **kwargs)
@@ -41,6 +59,7 @@ class UpdateTimeBaseModel(models.Model):
         abstract = True
 
 
+@python_2_unicode_compatible
 class UpdateUserBaseModel(models.Model):
     """
     Base model to automatically set:
@@ -49,20 +68,25 @@ class UpdateUserBaseModel(models.Model):
      
     Important: "threadlocals middleware" must be used!
     """
-    createby = models.ForeignKey(User, editable=False, related_name="%(class)s_createby",
-        null=True, blank=True, # <- If the model used outsite a real request (e.g. unittest, db shell)
+    createby = models.ForeignKey(settings.AUTH_USER_MODEL, editable=False, related_name="%(class)s_createby",
+        null=True, blank=True, # <- If the model used outside a real request (e.g. unittest, db shell)
         help_text="User how create this entry.")
-    lastupdateby = models.ForeignKey(User, editable=False, related_name="%(class)s_lastupdateby",
-        null=True, blank=True, # <- If the model used outsite a real request (e.g. unittest, db shell)
+    lastupdateby = models.ForeignKey(settings.AUTH_USER_MODEL, editable=False, related_name="%(class)s_lastupdateby",
+        null=True, blank=True, # <- If the model used outside a real request (e.g. unittest, db shell)
         help_text="User as last edit this entry.")
 
+    def __str__(self): # to be overwritten
+        return "model instance ID:%s" % self.pk
+
     def save(self, *args, **kwargs):
         current_user = ThreadLocal.get_current_user()
 
-        if current_user and isinstance(current_user, User):
-            if self.pk == None or kwargs.get("force_insert", False): # New model entry
-                self.createby = current_user
-            self.lastupdateby = current_user
+        if current_user:
+            User = get_user_model()
+            if isinstance(current_user, User):
+                if self.pk == None or kwargs.get("force_insert", False): # New model entry
+                    self.createby = current_user
+                self.lastupdateby = current_user
 
         return super(UpdateUserBaseModel, self).save(*args, **kwargs)
 
